# ImandraX Tools

Common utilities for interacting with ImandraX / IML, for both humans and LLMs.

Umbrella package that bundles [iml-query](../iml-query) and [imandrax-api-models](../imandrax-api-models)
